@@ -43,24 +43,21 @@ class FiwareIotClient(BaseClient):
         """
         logging.info("Creating service")
 
+        response = None
+
         if api_key:
             response = self._create_service(service, service_path, api_key)
+            response['api_key'] = api_key
 
-        else:
-            api_key = self.generate_api_key()
+        retries = 0
+        while retries < 5:
+            generated_api_key = self.generate_api_key()
+            response = self._create_service(service, service_path, generated_api_key)
+            if response and response['status_code'] == 201:
+                response['api_key'] = generated_api_key
+                break
+            retries += 1
 
-            created = False
-            response = None
-
-            while not created:
-                response = self._create_service(service, service_path, api_key)
-
-                if response['status_code'] == 201:
-                    created = True
-                else:
-                    api_key = self.generate_api_key()
-
-        response['api_key'] = api_key
         return response
 
     def _create_service(self, service, service_path, api_key):
